@@ -1,5 +1,5 @@
 package Game::Battleship::Player;
-$Game::Battleship::Player::VERSION = '0.0601';
+$Game::Battleship::Player::VERSION = '0.0602';
 our $AUTHORITY = 'cpan:GENE';
 
 use Carp;
@@ -188,7 +188,7 @@ Game::Battleship::Player
 
 =head1 VERSION
 
-version 0.0601
+version 0.0602
 
 =head1 SYNOPSIS
 
@@ -211,15 +211,11 @@ version 0.0601
 A C<Game::Battleship::Player> object represents a Battleship player
 complete with fleet and game surface.
 
-=head1 NAME
-
-Game::Battleship::Player - A Battleship player class
-
 =head1 PUBLIC METHODS
 
 =over 4
 
-=item B<new> %ARGUMENTS
+=item new
 
   $player => Game::Battleship::Player->new(
       name  => 'Aaron',
@@ -267,13 +263,11 @@ ten by ten grid is used.
 
 =back
 
-=item B<BUILD>
+=for Pod::Coverage BUILD
 
-Setup
+=item matrix
 
-=item B<matrix>
-
-  $grid = $player->matrix();
+  $grid = $player->matrix;
   $grid = $player->matrix($enemy);
 
 Return the playing grid as a "flush-left" text matrix like this:
@@ -289,7 +283,7 @@ Return the playing grid as a "flush-left" text matrix like this:
   . . . . . A . . . B
   . . . . . A . . . B
 
-=item B<strike> $PLAYER, @COORDINATE
+=item strike
 
   $strike = $player->strike($enemy, $x, $y);
 
@@ -315,7 +309,7 @@ grid" at the given coordinate and a zero (i.e. false) is returned.
 If a player calls for a strike at a coordinate that was already
 struck, a warning is emitted and a negative one (-1) is returned.
 
-=item B<craft> $KEY [$VALUE]
+=item craft
 
   $craft = $player->craft($id);
   $craft = $player->craft(id => $id);
@@ -333,7 +327,7 @@ be the C<id> attribute.
 
 =over 4
 
-=item B<_is_a_hit> @COORDINATE
+=item _is_a_hit
 
 Return true or false if another player's strike is successful.  That
 is, return a one if there is a craft at the given coordinate and zero
@@ -356,19 +350,11 @@ L<Game::Battleship::Grid>
 
 =head1 AUTHOR
 
-Gene Boggs E<lt>gene@cpan.orgE<gt>
-
-=head1 COPYRIGHT AND LICENSE
-
-See L<Game::Battleship>.
-
-=head1 AUTHOR
-
 Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Gene Boggs.
+This software is copyright (c) 2020 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
